@@ -43,11 +43,20 @@ func newBuildCmd() *buildCmd {
 		Use:     "build",
 		Aliases: []string{"b"},
 		Short:   "Builds the current project",
-		Long: `The build command allows you to execute only a subset of the pipeline, i.e. only the build step with its dependencies.
+		Long: `The ` + "`goreleaser build`" + ` command is analogous to the
+` + "`go build`" + ` command, in the sense it only builds binaries.
 
-It allows you to quickly check if your GoReleaser build configurations are doing what you expect.
+Its itented usage is, for example, within Makefiles to avoid setting up
+ldflags and etc in several places. That way, the GoReleaser config becomes the
+source of truth for how the binaries should be built.
 
-Finally, it allows you to generate a local build for your current machine only using the ` + "`--single-target`" + ` option, and specific build IDs using the ` + "`--id`" + ` option.
+It also allows you to generate a local build for your current machine only using
+the ` + "`--single-target`" + ` option, and specific build IDs using the
+` + "`--id`" + ` option in case you have more than one.
+
+When using ` + "`--single-target`" + `, the ` + "`GOOS`" + ` and
+` + "`GOARCH`" + ` environment variables are used to determine the target,
+defaulting to the current's machine target if not set.
 `,
 		SilenceUsage:  true,
 		SilenceErrors: true,
@@ -98,7 +107,7 @@ func buildProject(options buildOpts) (*context.Context, error) {
 		return nil, err
 	}
 	return ctx, ctrlc.Default.Run(ctx, func() error {
-		for _, pipe := range pipeline.BuildPipeline {
+		for _, pipe := range pipeline.BuildCmdPipeline {
 			if err := skip.Maybe(
 				pipe,
 				logging.Log(
